@@ -86,7 +86,7 @@ void UnitTestBase::verifyExists(const QString &uid, bool exists)
     waitForIt();
     calendar->deleteLater();
 
-    QCOMPARE(calendar->incidence(uid) != 0, exists);
+    QCOMPARE(calendar->incidence(uid) != nullptr, exists);
 }
 
 Akonadi::Item::List UnitTestBase::calendarItems()
@@ -169,6 +169,7 @@ QByteArray UnitTestBase::readFile(const QString &filename)
 {
     QFile file(filename);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        qWarning() << "File could not be opened for reading:" << filename;
         return QByteArray();
     }
 
