@@ -354,13 +354,12 @@ void ETMCalendarPrivate::onDataChanged(const QModelIndex &topLeft,
     // We only update collections, because items are handled in the filtered model
     Q_ASSERT(topLeft.row() <= bottomRight.row());
     const int endRow = bottomRight.row();
-    for (int row = topLeft.row(); row <= endRow; row++) {
+    for (int row = topLeft.row(); row <= endRow; ++row) {
         const Akonadi::Collection col = collectionFromIndex(topLeft.sibling(row, 0));
         if (col.isValid()) {
             // Attributes might have changed, store the new collection and discard the old one
             mCollectionMap.insert(col.id(), col);
         }
-        ++row;
     }
 }
 
