@@ -31,7 +31,7 @@ ITIPHandler::Private::Private(ITIPHandlerComponentFactory *factory, ITIPHandler
     , m_method(KCalCore::iTIPNoMethod)
     , m_helper(new ITIPHandlerHelper(m_factory))
     , m_currentOperation(OperationNone)
-    , m_uiDelegate(Q_NULLPTR)
+    , m_uiDelegate(nullptr)
     , m_showDialogsOnError(true)
     , q(qq)
 {
@@ -102,9 +102,9 @@ void ITIPHandler::Private::onLoadFinished(bool success, const QString &errorMess
                                   m_queuedInvitation.iCal,
                                   m_queuedInvitation.action);
         } else {
-            emit q->iTipMessageSent(ResultError, i18n("Error loading calendar: %1", errorMessage));
+            emit q->iTipMessageProcessed(ResultError, i18n("Error loading calendar: %1", errorMessage));
         }
-    } else if (m_currentOperation ==  OperationSendiTIPMessage) {
+    } else if (m_currentOperation == OperationSendiTIPMessage) {
         q->sendiTIPMessage(m_queuedInvitation.method,
                            m_queuedInvitation.incidence,
                            m_parentWidget);
